Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func InterceptorLogger ¶
InterceptorLogger creates a logging.Logger that automatically extracts Azure headers from the gRPC context. This is the default implementation that uses common.GetFields to extract standard Azure headers like correlation-id, operation-id, request-id, and arm-client-request-id from gRPC metadata.
func InterceptorLoggerWithHeadersFunc ¶ added in v0.0.39
func InterceptorLoggerWithHeadersFunc(logger *log.Logger, headersFunc HeadersFunc) logging.Logger
InterceptorLoggerWithHeadersFunc creates a logging.Logger with custom header extraction logic. This provides flexibility to customize which headers are extracted from the context. Pass nil as headersFunc to use the default common.GetFields header extraction.
Types ¶
Click to show internal directories.
Click to hide internal directories.